==========
Hanabython
==========


.. image:: https://img.shields.io/pypi/v/hanabython.svg
        :target: https://pypi.python.org/pypi/hanabython

.. image:: https://img.shields.io/travis/francois-durand/hanabython.svg
        :target: https://travis-ci.org/francois-durand/hanabython

.. image:: https://readthedocs.org/projects/hanabython/badge/?version=latest
        :target: https://hanabython.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




A Python implementation of Hanabi, a game by Antoine Bauza


* Free software: GNU General Public License v3
* Documentation: https://hanabython.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
